////////////////////////////////////////////////
// @运行时
////////////////////////////////////////////////

if (typeof (GSApp.API) == "undefined")
{
    GSApp.API = function () { };
}

////////////////////////////////////////////////
// @内容操作
////////////////////////////////////////////////

GSApp.API.ContentOperate = function () { };

////////////////////////////////////////////////
// @点赞，踩内容的相关API
////////////////////////////////////////////////

/**
 * 文章点赞信息，结构未：
 * contentId {int} 文章内容Id。
 * praisesCount {int} 文章点赞数量。
 * praised {bool} 当前用户是否已点赞。
 */
GSApp.API.ContentOperate.PraiseInfo = function (contentId, praisesCount, praised)
{
    if (typeof (contentId) == "undefined")
    {
        this.contentId = 0;
    }
    else
    {
        this.contentId = contentId;
    }

    if (typeof (praisesCount) == "undefined")
    {
        this.praisesCount = 0;
    }
    else
    {
        this.praisesCount = praisesCount;
    }

    if (typeof (praised) == "undefined")
    {
        this.praised = 0;
    }
    else
    {
        this.praised = false;
    }
}

/**
 * 使用指定的文章内容Id，获取文章内容的点赞信息。
 *
 * @param {int} contentId 指定的文章内容Id。
 * @param {function} didReceivePraiseInfo 接收文章点赞信息的回调函数，拥有唯一参数：GSApp.API.ContentOperate.PraiseInfo。
 * @returns
 */
GSApp.API.ContentOperate.getPraiseInfoWithContentId = function (contentId, didReceivePraiseInfo)
{
    if (didReceivePraiseInfo == null ||
        typeof (didReceivePraiseInfo) == "undefined")
    {
        return;
    }

    if (typeof (contentId) == "undefined")
    {
        didReceivePraiseInfo(new GSApp.API.ContentOperate.PraiseInfo());
        return;
    }

    var appCallback = new GSApp.API.AppCallback(function (response)
    {
        // !!!
        didReceivePraiseInfo(response);
        // !!!
    })

    var urlCommand
        = "GSApp://get.praiseInfo.content.app?{"
        + "\"contentType\":\"" + kContentType + "\""
        + ", \"contentId\":\"" + kContentId + "\""
        + ", \"callback\":\"" + appCallback.functionName + "\"}";
    GSApp.API.processURLCommand(urlCommand);
}

/**
 * 使用指定的文章内容Id，点赞指定的文章。
 *
 * @param {int} contentId 指定的文章内容Id。
 * @param {function} didReceivePraisedResult 接收文章点赞是否成功的回调函数。
 * @returns
 */
GSApp.API.ContentOperate.praiseContent = function (contentId, didReceivePraisedResult)
{
    if (didReceivePraisedResult == null ||
        typeof (didReceivePraisedResult) == "undefined")
    {
        return;
    }

    if (typeof (contentId) == "undefined")
    {
        didReceivePraisedResult(false);
        return;
    }

    var appCallback = new GSApp.API.AppCallback(function (response)
    {
        if (typeof (response) == "undefined")
        {
            response = true;
        }

        // !!!
        didReceivePraisedResult(response);
        // !!!
    })

    var urlCommand
        = "GSApp://praise.praiseInfo.content.app?{\"contentType\":\""
        + kContentType + "\""
        + ", \"contentId\":\"" + contentId + "\""
        + ", \"callback\":\"" + appCallback.functionName + "\"}";
    GSApp.API.processURLCommand(urlCommand);
}

/**
 * 点赞当前文章。
 *
 * @param {function} didReceivePraisedResult 接收文章点赞是否成功的回调函数。
 * @returns
 */
GSApp.API.ContentOperate.praiseCurrentContent = function (didReceivePraisedResult)
{
    GSApp.API.ContentOperate.praiseContent(kContentId, didReceivePraisedResult)
}

/**
 * 使用指定的文章内容Id，踩指定的文章。
 *
 * @param {int} contentId 指定的文章内容Id。
 * @param {function} didReceiveTreadResult 接收文章点赞是否成功的回调函数。
 * @returns
 */
GSApp.API.ContentOperate.treadContent = function (contentId, didReceiveTreadResult)
{
    if (typeof (contentId) == "undefined")
    {
        if (typeof (didReceiveTreadResult) != "undefined"
            && didReceiveTreadResult != null)
        {
            didReceiveTreadResult(false);
        }
        return;
    }

    var appCallback = new GSApp.API.AppCallback(function (response)
    {
        // !!!
        if (typeof (didReceiveTreadResult) != "undefined"
            && didReceiveTreadResult != null)
        {
            didReceiveTreadResult(response);
        }
        // !!!
    })

    var urlCommand
        = "GSApp://tread.praiseInfo.content.app?{\"contentType\":\""
        + kContentType + "\""
        + ", \"contentId\":\"" + contentId + "\""
        + ", \"callback\":\"" + appCallback.functionName + "\"}";
    GSApp.API.processURLCommand(urlCommand);
}

/**
 * 踩当前文章。
 *
 * @param {function} didReceiveTreadResult 接收文章点赞是否成功的回调函数。
 * @returns
 */
GSApp.API.ContentOperate.treadCurrentContent = function (didReceiveTreadResult)
{
    GSApp.API.ContentOperate.treadContent(kContentId, didReceiveTreadResult)
}

////////////////////////////////////////////////
// @收藏内容的相关API
////////////////////////////////////////////////

/**
 * 使用指定的文章内容Id，收藏指定的文章。
 *
 * @param {string} contentType 指定的文章内容类型。
 * @param {int} contentId 指定的文章内容Id。
 * @param {function} didReceiveCollectResult 接收文章收藏是否成功的回调函数。
 * @returns
 */
GSApp.API.ContentOperate.collectWithContentType = function (contentType, contentId, didReceiveCollectResult)
{
    if (typeof (contentId) == "undefined")
    {
        if (typeof (didReceiveCollectResult) != "undefined"
            && didReceiveCollectResult != null)
        {
            didReceiveCollectResult(false);
        }
        return;
    }

    var appCallback = new GSApp.API.AppCallback(function (response)
    {
        // !!!   
        if (typeof (didReceiveCollectResult) != "undefined"
            && didReceiveCollectResult != null)
        {
            didReceiveCollectResult(response);
        }
        // !!!
    });

    var urlCommand
        = "GSApp://collect.content.app?{\"contentType\":\"" + contentType + "\""
        + ", \"contentId\":\"" + contentId + "\""
        + ", \"action\":\"collect\""
        + ", \"callback\":\"" + appCallback.functionName + "\"}";
    GSApp.API.processURLCommand(urlCommand);
}


/**
 * 收藏当前文章内容。
 *
 * @param {function} didReceiveCollectResult 接收文章收藏是否成功的回调函数。
 */
GSApp.API.ContentOperate.collectCurrentContent = function (didReceiveCollectResult)
{
    GSApp.API.ContentOperate.collectWithContentType(kContentType, kContentId, didReceiveCollectResult);
}


/**
 * 使用指定的文章内容Id，取消收藏指定的文章。
 *
 * @param {string} contentType 指定的文章内容类型。
 * @param {int} contentId 指定的文章内容Id。
 * @param {function} didReceiveCancelCollectResult 接收文章取消收藏是否成功的回调函数。
 * @returns
 */
GSApp.API.ContentOperate.cancelCollectWithContentType = function (contentType, contentId, didReceiveCancelCollectResult)
{
    if (typeof (contentId) == "undefined")
    {
        if (typeof (didReceiveCancelCollectResult) != "undefined"
            && didReceiveCancelCollectResult != null)
        {
            didReceiveCancelCollectResult(false);
        }
        return;
    }

    var appCallback = new GSApp.API.AppCallback(function (response)
    {
        // !!!
        if (typeof (didReceiveCancelCollectResult) != "undefined"
            && didReceiveCancelCollectResult != null)
        {
            didReceiveCancelCollectResult(response);
        }
        // !!!
    })

    var urlCommand
        = "GSApp://collect.content.app?{\"contentType\":\"" + contentType + "\""
        + ", \"contentId\":\"" + contentId + "\""
        + ", \"action\":\"cancelCollect\""
        + ", \"callback\":\"" + appCallback.functionName + "\"}";
    GSApp.API.processURLCommand(urlCommand);
}


/**
 * 取消收藏当前文章内容。
 *
 * @param {function} didReceiveCollectResult 接收文章收藏是否成功的回调函数。
 */
GSApp.API.ContentOperate.cancelCollectCurrentContent = function (didReceiveCancelCollectResult)
{
    GSApp.API.ContentOperate.collectWithContentType(kContentType, kContentId, didReceiveCancelCollectResult);
}


/**
 * 使用指定的文章内容Id，获取文章内容的收藏状态。
 *
 * @param {int} contentId 指定的文章内容Id。
 * @param {function} didReceiveCollectState 接收文章是否收藏的回调函数。
 * @returns
 */
GSApp.API.ContentOperate.isContentCollected = function (contentId, didReceiveCollectState)
{
    if (didReceiveCollectState == null ||
        typeof (didReceiveCollectState) == "undefined")
    {
        return;
    }

    if (typeof (contentId) == "undefined")
    {
        didReceiveCollectState(false);
        return;
    }

    var appCallback = new GSApp.API.AppCallback(function (response)
    {
        // !!!
        didReceiveCollectState(response);
        // !!!
    })

    var urlCommand
        = "GSApp://isCollected.content.app?{\"contentId\":\"" + contentId + "\""
        + ", \"callback\":\"" + appCallback.functionName + "\"}";
    GSApp.API.processURLCommand(urlCommand);
}


/**
 * 获取当前文章内容的收藏状态。
 *
 * @param {function} didReceiveCollectState 接收文章是否收藏的回调函数。
 * @returns
 */
GSApp.API.ContentOperate.isCurrentContentCollected = function (didReceiveCollectState)
{
    GSApp.API.ContentOperate.isContentCollected(kContentId, didReceiveCollectState);
}

////////////////////////////////////////////////
// @分析内容的相关API
////////////////////////////////////////////////

/**
 * 分析内容到指定的平台。
 *
 * @param {*} sharePlatform 指定的分析平台名称，可选值有：quanBu，weiXin，pengYouQuan，qq。
 * @param {*} title 要分享的内容标题。
 * @param {*} thumbnailUrl 要分享的缩略图Url。
 * @param {*} subtitle 要分享的内容副标题。
 * @param {*} contentUrl 要分享的内容Url。
 * @param {*} lotteryId 分享涉及的抽奖活动Id。
 * @param {*} didReceiveShareResult 接收分享结果的回调函数，拥有唯一参数：isShareCompleted。
 */
GSApp.API.ContentOperate.shareContentToPlatform = function (
    sharePlatform,
    title,
    thumbnailUrl,
    subtitle,
    contentUrl,
    lotteryId,
    didReceiveShareResult)
{
    var appCallback = new GSApp.API.AppCallback(function (response)
    {
        // !!!
        didReceiveShareResult(response);
        // !!!
    });

    var urlCommand = "";
    if (GSApp.API.isAndroid())
    {
        urlCommand
            = "GSApp://share.app?{\"platform\":\""
            + sharePlatform
            + "\",\"type\":\"url\",\"title\":\""
            + title
            + "\",\"originURL\":\""
            + contentUrl
            + "\",\"subtitle\":\""
            + subtitle
            + "\",\"thumbnailURL\":\""
            + thumbnailUrl
            + "\",\"lotteryId\":\""
            + lotteryId
            + "\",\"callback\":\"" + appCallback.functionName + "\"}";
    }
    else
    {
        urlCommand
            = "GSApp://share.app?{\"platform\":\""
            + sharePlatform
            + "\",\"type\":\"url\",\"title\":\""
            + title
            + "\",\"URL\":\""
            + contentUrl
            + "\",\"subTitle\":\""
            + subtitle
            + "\",\"thumbnailURL\":\""
            + thumbnailUrl
            + "\",\"lotteryId\":\""
            + lotteryId
            + "\",\"callback\":\"" + appCallback.functionName + "\"}";
    }
    // !!!
    GSApp.API.processURLCommand(urlCommand);
    // !!!
}

/**
 * 为当前内容展示分享菜单。 
 *
 * @param {*} didReceiveShareResult 接收分享结果的回调函数，拥有唯一参数：isShareCompleted。
 */
GSApp.API.ContentOperate.showShareMenu = function (didReceiveShareResult)
{
    GSApp.API.ContentOperate.shareContentToPlatform(
        "quanBu",
        kShareContentTitle,
        kContentThumbnail,
        kShareContentSubtitle,
        kContentURL,
        0,
        didReceiveShareResult);
}

/**
 * 将当前内容分享到指定的平台。 
 *
 * @param {*} sharePlatform 指定的分析平台名称，可选值有：quanBu，weiXin，pengYouQuan，qq。
 * @param {*} didReceiveShareResult 接收分享结果的回调函数，拥有唯一参数：isShareCompleted。
 */
GSApp.API.ContentOperate.shareCurrentContentToPlatform = function (
    sharePlatform,
    didReceiveShareResult)
{
    GSApp.API.ContentOperate.shareContentToPlatform(
        sharePlatform,
        kShareContentTitle,
        kContentThumbnail,
        kShareContentSubtitle,
        kContentURL,
        0,
        didReceiveShareResult);
}