////////////////////////////////////////////////
// @运行时
////////////////////////////////////////////////

if (typeof (GSApp.API) == "undefined")
{
    GSApp.API = function () { };
}

////////////////////////////////////////////////
// @用户信息API
////////////////////////////////////////////////

GSApp.API.UserInfo = function () { };

////////////////////////////////////////////////
// @用户信息
////////////////////////////////////////////////

/**
 * 使用指定的用户Id数组，获取对应的用户信息。
 *
 * @param {array} userIds, 要获取用户信息的用户Id数组。
 * @param {function} didReceiveUserInfes, 用于接收用户信息的回调函数，拥有唯一参数：GSApp.Modules.UserInfo[]，用户信息数组。
 * @returns 没有返回值。
 */
GSApp.API.UserInfo.getUserInfesWithUserIds = function (userIds, didReceiveUserInfes)
{

    if (didReceiveUserInfes == null ||
        typeof (didReceiveUserInfes) == "undefined")
    {
        return;
    }

    if (userIds == null ||
        !(userIds instanceof Array) ||
        userIds.length < 1)
    {
        didReceiveUserInfes(new Array());
        return;
    }

    var appCallback = new GSApp.API.AppCallback(function (response)
    {
        try
        {
            if (response.result != null &&
                response.result != undefined)
            {
                response = response.result;
            } else
            {
                response = response;
            }

            var userInfes = new Array();
            if (response != null &&
                response instanceof Array)
            {
                // !!!
                userInfes = response;
                // !!!
            }
        } catch (exception)
        {
            console.log(exception);
            //
            userInfes = new Array();
        }
        // !!!
        didReceiveUserInfes(userInfes);
        // !!!
    })

    var userIdsParam = "";
    userIds.forEach(function (userId)
    {
        if (userIdsParam.length > 0)
        {
            userIdsParam += ",";
        }
        userIdsParam += userId;
    });

    GSApp.API.post(
        "http://appapi2.gamersky.com/v5/getUserInfesList",
        "JSON",
        "{\"userIds\":\"" + userIdsParam + "\",\"cacheMinutes\":120}",
        true,
        appCallback);
}

/**
 * 获取单个用户的用户信息。
 *
 * @param {string} userId, 要获取用户信息的用户Id。
 * @param {function} didReceiveUserInfo, 用于接收用户信息的回调函数，拥有唯一参数：GSApp.Modules.UserInfo，用户信息对象。
 * @returns 没有返回值。
 */
GSApp.API.UserInfo.getUserInfoWithUserId = function (userId, didReceiveUserInfo)
{
    if (didReceiveUserInfo == null ||
        typeof (didReceiveUserInfo) == "undefined")
    {
        return;
    }

    if (userId == 0)
    {
        didReceiveUserInfes(null);
        return;
    }

    // !!!
    GSApp.API.UserInfo.getUserInfesWithUserIds(
        [userId],
        function (userInfes)
        {
            var userInfo = null;
            if (userInfes.length > 0)
            {
                userInfo = userInfes[0];
            }
            // !!!
            didReceiveUserInfo(userInfo);
            // !!!
        });
    // !!!
}

GSApp.API.UserInfo.currentUser_WatchUser = function (userId, didReceiveWatchResult)
{
    if (typeof (userId) == "undefined"
        || userId == null)
    {
        return;
    }
    if (typeof (didReceiveWatchResult) == "undefined"
        || didReceiveWatchResult == null)
    {
        return;
    }

    var appCallback
        = new GSApp.API.AppCallback(didReceiveWatchResult);

    var urlCommand
        = "GSApp://set.followed.app?{\"authorId\":\""
        + userId
        + "\",\"operateName\":\"follow\",\"callBack\":\"" + appCallback.functionName + "\"}";
    { }
    GSApp.API.processURLCommand(urlCommand);
    console.log("关注用户:" + userId);
}

GSApp.API.UserInfo.currentUser_CancelWatchUser = function (userId, didReceiveWatchResult)
{
    if (typeof (userId) == "undefined"
        || userId == null)
    {
        return;
    }
    if (typeof (didReceiveWatchResult) == "undefined"
        || didReceiveWatchResult == null)
    {
        return;
    }

    var appCallback
        = new GSApp.API.AppCallback(didReceiveWatchResult);

    var urlCommand
        = "GSApp://set.followed.app?{\"authorId\":\""
        + userId
        + "\",\"operateName\":\"unfollow\",\"callBack\":\"" + appCallback.functionName + "\"}";
    { }
    GSApp.API.processURLCommand(urlCommand);
    console.log("取消关注用户:" + userId);
}

GSApp.API.UserInfo.isUserIdCurrentUserWatched = function (userId, didReceiveIsWatched)
{
    if (didReceiveIsWatched == null ||
        typeof (didReceiveIsWatched) == "undefined")
    {
        return;
    }

    var appCallback = new GSApp.API.AppCallback(didReceiveIsWatched);

    var urlCommand = "GSApp://get.followed.app?{\"authorId\":\"" +
        userId + "\",\"callBack\":\"" +
        appCallback.functionName + "\"}";
    GSApp.API.processURLCommand(urlCommand);
}