////////////////////////////////////////////////
// @运行时
////////////////////////////////////////////////
if (typeof (GSApp.API) == "undefined")
{
    GSApp.API = function () { };
}

// 0 未知, 1 Android, 2 iOS
GSApp.API.SystemType = 0;
GSApp.API.HTMLElement = document.getElementsByTagName("html")[0];
if (kOS == "android")
{
    GSApp.API.SystemType = 1;
}
else if (kOS == "ios")
{
    GSApp.API.SystemType = 2;
}

GSApp.API.isAndroid = function ()
{
    return GSApp.API.SystemType == 1;
}

GSApp.API.isIOS = function ()
{
    return GSApp.API.SystemType == 2;
}

// App版本号。
GSApp.API.AppVersionNumber = kAppVersion;
// App版本号纯数字。
GSApp.API.AppVersionNumber = parseInt(kAppVersion.replaceAll("\\.", ""));


GSApp.API.applyPageOption = function (uiMode, fontSize)
{
    try
    {
        var htmlTagCSSClassName = "";
        {
            // 操作系统：
            if (GSApp.API.SystemType == 1)
            {
                htmlTagCSSClassName = "Android";
            }
            else if (GSApp.API.SystemType == 2)
            {
                htmlTagCSSClassName = "iOS";
            }


            // 日夜间模式：
            if (htmlTagCSSClassName.length > 0)
            {
                htmlTagCSSClassName += " ";
            }
            if (uiMode == "night")
            {
                htmlTagCSSClassName += "PageColorMode_Night";
            }
            else
            {
                htmlTagCSSClassName += "PageColorMode_Day";
            }

            // 字体大小：
            if (htmlTagCSSClassName.length > 0)
            {
                htmlTagCSSClassName += " ";
            }
            if (fontSize == "big")
            {
                htmlTagCSSClassName += "PageFontSize_Max";
            }
            else if (fontSize == "small")
            {
                htmlTagCSSClassName += "PageFontSize_Min";
            }
            else
            {
                htmlTagCSSClassName += "PageFontSize_Middle";
            }

            // 内容类型：
            var contentTypeCSSClassName = "";
            switch (kContentType)
            {
                case "xinWen":
                case "news":
                    {
                        contentTypeCSSClassName = "XinWen";
                    } break;
                case "gongLue":
                case "strategy":
                    {
                        contentTypeCSSClassName = "GongLue";
                    } break;
                case "zhuanLan":
                    {
                        contentTypeCSSClassName = "ZhuanLan";
                    } break;
                case "shiPin":
                    {
                        contentTypeCSSClassName = "ShiPin";
                    } break;
                case "zhuTi.quanZi":
                    {
                        contentTypeCSSClassName = "QuanZiZhuTi";
                    } break;
            }
            if (contentTypeCSSClassName.length > 0)
            {
                if (htmlTagCSSClassName.length > 0)
                {
                    htmlTagCSSClassName += " ";
                }
                htmlTagCSSClassName += contentTypeCSSClassName;
            }
        }
        // !!!
        document.getElementsByTagName("html")[0].className = htmlTagCSSClassName;
        // !!!
    }
    catch (error)
    {
        console.log(error);
    }
};
////////////////////////////////////////////////
////////////////////////////////////////////////
////////////////////////////////////////////////
// !!!
GSApp.API.applyPageOption(kDefaultPageColorMode, kDefaultPageFontSize);
// !!!
////////////////////////////////////////////////
////////////////////////////////////////////////
////////////////////////////////////////////////

/**
 * GSApp回调对象，使用指定的函数名称，生成App回调函数。
 *
 * @param {function} executionContent 函数的执行内容。
 * @returns 返回App回调函数对象。
 */
GSApp.API.AppCallback = function (executionContent)
{
    var randomFunctionName = "gsAppCallback_" +
        Math.random().toString(36).slice(-10) +
        Math.random().toString(36).slice(-10) +
        Math.random().toString(36).slice(-2); {
        randomFunctionName = randomFunctionName.replace(/\./g, '_');
    }
    // !!!
    window[randomFunctionName] = function (response)
    {
        if (typeof (response) == "string")
        {
            response = decodeURIComponent(response);
            response = JSON.parse(response);
        }

        // !!!
        if (typeof (executionContent) != "undefined")
        {
            executionContent(response);
        }
        // !!!
    };
    // !!!
    return {
        functionName: randomFunctionName
    };
}

/**
 * 执行“GSApp URL命令”。
 *
 * @param string urlCommand
 * @returns 没有返回值。
 */
GSApp.API.processURLCommand = function (urlCommand)
{
    if (!urlCommand ||
        urlCommand.length < 1)
    {
        return;
    }

    var indexOfQuestionMark = urlCommand.indexOf("?");
    if (indexOfQuestionMark >= 0)
    {
        var path = urlCommand.substring(0, indexOfQuestionMark);
        var query = "";
        var queryBeginIndex = indexOfQuestionMark + 1;
        if (queryBeginIndex < urlCommand.length)
        {
            query = urlCommand.substring(queryBeginIndex, urlCommand.length);
            query = encodeURIComponent(query);
        }
        urlCommand = path + "?" + query;
    }

    try
    {

        var aTag = document.createElement("A");
        {
            aTag.href = urlCommand;
        }
        aTag.click();
    }
    catch (error)
    {
        if (GSApp.API.isAndroid())
        {
            location.href = urlCommand;
        }
    }
};


/**
 * 由App发送可跨域的HTTP请求。
 *
 * @param {string} url, 目标URL。
 * @param {GET/JSON/FORM} type, 发送请求的类型，可选值有：GET，JSON，FORM。
 * @param {string} postData, 要发送的请求数据，JSON格式。
 * @param {boolean} useAPIHeader, 标记是否请求要携带“APP API 头”。
 * @param {function} didReceiveResponse, 用于接收请求接口的回调函数，必须位于“window”对象。
 * @returns 没有返回值。
 */
GSApp.API.post = function (url, type, postData, useAPIHeader, didReceiveResponse)
{
    if (url == null ||
        url.length < 1)
    {
        return;
    }

    /* 不对回调对象做检查，以暴露异常。
    if (didReceiveResponse == null)
    {
        return;
    }
    */

    if (postData == null)
    {
        postData = "";
    } else if (postData.length > 0)
    {
        postData = postData.replaceAll("\"", "\\\"");
    }

    if (useAPIHeader == null ||
        typeof (useAPIHeader) == "undefined" ||
        !useAPIHeader)
    {
        useAPIHeader = "false";
    } else
    {
        useAPIHeader = "true";
    }

    // #AppAPI#
    var urlCommand = "GSApp://post.app?{" +
        "\"url\":\"" + url + "\", " +
        "\"type\":\"" + type + "\"," +
        "\"data\":\"" + postData + "\"," +
        "\"useAPIHeader\":" + useAPIHeader + ", " +
        "\"callback\":\"" + didReceiveResponse.functionName + "\"}"; { }
    GSApp.API.processURLCommand(urlCommand);
}