
////////////////////////////////////////////////
// @运行时
////////////////////////////////////////////////

if (typeof (GSApp) == "undefined")
{
    GSApp = function () { };
}

////////////////////////////////////////////////
// @UI控件
////////////////////////////////////////////////


GSApp.UIControls = function () { };

// 列表场景（如新闻节点页，相关推荐区块等）
// 时间段			规则                                  示例
// 当日(0点后)		显示24小时制时间		17: 38
// 当日前（0点前）	显示昨日 + 24小时制时间	昨日09: 12
// 大于一天前		显示日期				10月14日
// 注意：
// 月日的数字，不需要补零，如：9月1日
// 时间的数字，需要补零，如：08: 01
GSApp.UIControls.captionOfTimeInList = function (time)
{
    if (typeof (time) == "undefined"
        || time == null)
    {
        return "";
    }

    var timeInterval = 0;
    if (time instanceof Date)
    {
        timeInterval = time.getTime();
    }
    else if (typeof (time) == "number")
    {
        timeInterval = time;
        if (timeInterval < 1000000000000)
        {
            timeInterval *= 1000;
        }
        // !!!
        time = new Date(timeInterval);
        // !!!
    }



    var kSecond = 1000;
    var kMinute = 1000 * 60;
    var kHour = kMinute * 60;
    var kDay = kHour * 24;

    var now = new Date();
    var timeIntervalOfNow = now.getTime();
    var timeIntervalOfTodayZero = timeIntervalOfNow -
        now.getMilliseconds() -
        kSecond * now.getSeconds() -
        kMinute * now.getMinutes() -
        kHour * now.getHours();
    var timeIntervalOfYesterday = timeIntervalOfTodayZero -
        kDay;
    // 当日(0点后)		显示24小时制时间		17: 38
    if (timeInterval >= timeIntervalOfTodayZero)
    {
        var hourCaption = time.getHours().toString().complementZeroToIntNumberDigits(2);
        var minuteCaption = time.getMinutes().toString().complementZeroToIntNumberDigits(2);

        return hourCaption + ":" + minuteCaption;
    }
    // 当日前（0点前）	显示昨日 + 24小时制时间	昨日09: 12
    else if (timeInterval >= timeIntervalOfTodayZero)
    {
        var hourCaption = time.getHours().toString().complementZeroToIntNumberDigits(2);
        var minuteCaption = time.getMinutes().toString().complementZeroToIntNumberDigits(2);

        return "昨日" + hourCaption + ":" + minuteCaption;
    }
    // 大于一天前		显示日期				10月14日
    else
    {
        var monthCaption = (time.getMonth() + 1).toString(); //.complementZeroToIntNumberDigits(2);
        var dayCaption = time.getDate().toString(); //.complementZeroToIntNumberDigits(2);

        return monthCaption + "月" + dayCaption + "日";
    }
};

// 列表场景（如新闻节点页，相关推荐区块等）
// 时间段      规则                      示例
// 全部时间    显示发布时间的年月日时分。  2018-08-19 19:34
GSApp.UIControls.captionOfTimeInContent = function (time)
{
    if (typeof (time) == "undefined"
        || time == null)
    {
        return "";
    }

    var timeInterval = 0;
    if (time instanceof Date)
    {
        timeInterval = time.getTime();
    }
    else if (typeof (time) == "number")
    {
        timeInterval = time;
        if (timeInterval < 1000000000000)
        {
            timeInterval *= 1000;
        }
        // !!!
        time = new Date(timeInterval);
        // !!!
    }

    return time.getFullYear() +
        "-" + (time.getMonth() + 1) +
        "-" + time.getDate() +
        " " +
        time.getHours().toString().complementZeroToIntNumberDigits(2) +
        ":" +
        time.getMinutes().toString().complementZeroToIntNumberDigits(2);
};

GSApp.UIControls.textExpandButtonOnClick_Default = function ()
{
    var button = event.target;
    if (button == null
        || button.parentElement == null)
    {
        return;
    }

    var originalContent = button.getAttribute("gsAppExpandButton_OriginalContent");
    if (originalContent != null
        && originalContent.length > 0)
    {
        //
        originalContent = decodeURIComponent(originalContent);
        //
        button.parentElement.innerHTML = originalContent;
    }

    event.preventDefault();
    event.stopPropagation();
}

GSApp.UIControls.textToHtmlWithExpandButtonInMaxLength = function (text, maxLength, expandButtonCaption, expandButtonClickCode)
{
    if (text == null
        || text.length < maxLength
        || typeof (GSApp.XML) == "undefined")
    {
        return text;
    }

    var finalExpandButtonCaption = "展开";
    if (typeof (expandButtonCaption) != "undefined")
    {
        finalExpandButtonCaption = expandButtonCaption;
    }

    var finalExpandButtonOnClickCode = "GSApp.UIControls.textExpandButtonOnClick_Default();";
    if (typeof (expandButtonClickCode) != "undefined")
    {
        finalExpandButtonOnClickCode = expandButtonClickCode;
    }

    var rootHtmlNodes = GSApp.XML.parseHtml(text);
    if (rootHtmlNodes == null
        || rootHtmlNodes.length < 1
        || rootHtmlNodes.innerText == null
        || rootHtmlNodes.innerText.length < maxLength)
    {
        return text;
    }

    // 4 = "...展开" 
    var expandTextLength = 4;
    var expandButtonHtml
        = "..."
        + "<span class=\"GSAppExpandButton\" gsAppExpandButton_OriginalContent=\"" + encodeURIComponent(text) + "\" onclick=\"" + finalExpandButtonOnClickCode + "\">"
        + finalExpandButtonCaption
        + "</span>";

    var textLengthNeedOmitted
        = maxLength >= expandTextLength
            ? rootHtmlNodes.innerText.length - (maxLength - expandTextLength)
            : rootHtmlNodes.innerText.length;
    var htmlNodePathStack = new Array();
    {
        htmlNodePathStack.push(
            {
                htmlNodes: rootHtmlNodes,
                nextHtmlNodeIndex: rootHtmlNodes.length - 1
            });
    }
    while (htmlNodePathStack.length > 0
        && textLengthNeedOmitted > 0)
    {
        var htmlNodePath = htmlNodePathStack[htmlNodePathStack.length - 1];
        var htmlNodes = htmlNodePath.htmlNodes;
        var htmlNodeIndex = htmlNodePath.nextHtmlNodeIndex;
        for (;
            htmlNodeIndex >= 0;
            htmlNodeIndex--)
        {
            var htmlNode = htmlNodes[htmlNodeIndex];
            if (htmlNode.type == "TEXT")
            {
                if (textLengthNeedOmitted > htmlNode.text.length)
                {
                    //
                    htmlNodes.splice(htmlNodeIndex, 1)
                    // 
                    textLengthNeedOmitted -= htmlNode.text.length;
                }
                else
                {
                    htmlNode.text
                        = htmlNode.text.substring(
                            0,
                            htmlNode.text.length - textLengthNeedOmitted)
                        + expandButtonHtml;

                    // !!!
                    textLengthNeedOmitted = 0;
                    // !!!
                    break;
                    // !!!
                }
            }
            else if (htmlNode.children != null
                && htmlNode.children.length > 0)
            {
                htmlNodePath.nextHtmlNodeIndex = htmlNodeIndex - 1;
                htmlNodePathStack.push(
                    {
                        htmlNodes: htmlNode.children,
                        nextHtmlNodeIndex: htmlNode.children.length - 1
                    });
                // !!!
                break;
                // !!!
            }
            else // 当前为空标签：
            {
                //
                htmlNodes.splice(htmlNodeIndex, 1)
                // 
            }
        }
        if (htmlNodeIndex < 0)
        {
            htmlNodePathStack.length--;
        }
    }

    var htmlWithExpandButton
        = GSApp.XML.createHtml(rootHtmlNodes);
    if (htmlWithExpandButton == null
        && htmlWithExpandButton.length < 1)
    {
        htmlWithExpandButton = expandButtonHtml;
    }
    return htmlWithExpandButton;
}